# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later
"""DenseNet_, to be fine-tuned. Pre-trained on ImageNet_.

This configuration contains a version of DenseNet_ (c.f. `TorchVision's
page <alexnet_pytorch_>`), modified for a variable number of outputs
(defaults to 1).

N.B.: The output layer is **always** initialized from scratch.
"""

from torch.nn import BCEWithLogitsLoss
from torch.optim import Adam

from ptbench.data.augmentations import ElasticDeformation
from ptbench.models.densenet import Densenet

model = Densenet(
    train_loss=BCEWithLogitsLoss(),
    validation_loss=BCEWithLogitsLoss(),
    optimizer_type=Adam,
    optimizer_arguments=dict(lr=0.0001),
    augmentation_transforms=[ElasticDeformation(p=0.8)],
    pretrained=True,
)
