# Copyright © 2022 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

import importlib

import click

from clapper.click import AliasedGroup


@click.group(
    cls=AliasedGroup,
    context_settings=dict(help_option_names=["-?", "-h", "--help"]),
)
def cli():
    """Image classification benchmark."""
    pass


cli.add_command(importlib.import_module("..config", package=__name__).config)
cli.add_command(
    importlib.import_module("..database", package=__name__).database
)
cli.add_command(
    importlib.import_module("..evaluate", package=__name__).evaluate
)
cli.add_command(
    importlib.import_module("..experiment", package=__name__).experiment
)
cli.add_command(importlib.import_module("..predict", package=__name__).predict)
cli.add_command(importlib.import_module("..train", package=__name__).train)
cli.add_command(
    importlib.import_module("..train_analysis", package=__name__).train_analysis
)


@click.group(
    cls=AliasedGroup,
    context_settings=dict(help_option_names=["-?", "-h", "--help"]),
)
def saliency():
    """Sub-commands to generate, evaluate and view saliency maps."""
    pass


cli.add_command(saliency)

saliency.add_command(
    importlib.import_module("..saliency.generate", package=__name__).generate
)
saliency.add_command(
    importlib.import_module(
        "..saliency.completeness", package=__name__
    ).completeness
)
saliency.add_command(
    importlib.import_module(
        "..saliency.interpretability", package=__name__
    ).interpretability
)
saliency.add_command(
    importlib.import_module("..saliency.evaluate", package=__name__).evaluate
)
saliency.add_command(
    importlib.import_module("..saliency.view", package=__name__).view
)
